@@ -22,13 +22,13 @@ from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
 from opentelemetry.trace import get_tracer
 from wrapt import wrap_function_wrapper
 
+from langtrace_python_sdk.constants.instrumentation.weaviate import APIS
 from langtrace_python_sdk.instrumentation.weaviate.patch import (
     generic_collection_patch,
     generic_query_patch,
 )
-from langtrace_python_sdk.constants.instrumentation.weaviate import APIS
 
-logging.basicConfig(level=logging.FATAL)
+logging.basicConfig(level=logging.DEBUG)  # Set to DEBUG for detailed logging
 
 
 class WeaviateInstrumentation(BaseInstrumentor):
@@ -37,7 +37,7 @@ class WeaviateInstrumentation(BaseInstrumentor):
     """
 
     def instrumentation_dependencies(self) -> Collection[str]:
-        return ["weaviate-client >= 4.6.1", "trace-attributes >= 4.0.2"]
+        return ["weaviate-client >= 4.6.1", "trace-attributes >= 7.0.3"]
 
     def _instrument(self, **kwargs):
         tracer_provider = kwargs.get("tracer_provider")
@@ -45,8 +45,7 @@ class WeaviateInstrumentation(BaseInstrumentor):
         version = importlib.metadata.version("weaviate-client")
 
         for api_name, api_config in APIS.items():
-            module_path, function_name = api_name.rsplit(".", 1)
-            if api_config.get("OPERATION") == "query":
+            if api_config.get("OPERATION") in ["query", "generate"]:
                 wrap_function_wrapper(
                     api_config["MODULE"],
                     api_config["METHOD"],
